@@ -1,8 +1,9 @@
 import json
 import difflib
+import importlib.resources
 
-
-data = json.load(open("./dictionary/data.json", "r"))
+with importlib.resources.open_text("dictionary", "data.json") as file:
+    data = json.load(file)
 
 
 def pretty(word, definition):
@@ -34,7 +35,7 @@ def translate(word):
         if answer:
             return pretty(new_word[0], data[new_word[0]])
         else:
-            return print("Sorry, your word is not in the dictionary \n")
+            return print("Sorry, your word is not in the dictionary. \n")
 
     else:
-        return print("Sorry, your word is not in the dictionary \n")
+        return print("Sorry, your word is not in the dictionary. \n")
